Terminals
=========

Classes
-------

.. currentmodule:: ansys.edb.core.terminal

.. autosummary::
   :toctree: _autosummary

   terminal.BoundaryType
   bundle_terminal.BundleTerminal
   edge_terminal.Edge
   edge_terminal.EdgeTerminal
   edge_terminal.EdgeType
   terminal.HfssPIType
   edge_terminal.PadEdge
   padstack_instance_terminal.PadstackInstanceTerminal
   pin_group_terminal.PinGroupTerminal
   point_terminal.PointTerminal
   edge_terminal.PrimitiveEdge
   terminal.SourceTermToGroundType
   terminal.Terminal
   terminal_instance.TerminalInstance
   terminal_instance_terminal.TerminalInstanceTerminal
   terminal.TerminalType
